# ArToKi-Energy.py (c) 2015 Thierry Maes (tmaes)

bl_info = {
    "name": "ArToKi-Energy",
    "author": "Thierry Maes (tmaes)",
    "version": (0,0,10),
    "blender": (2, 8),
    "api": 56533,
    "location": "Properties > Material > ArToKi EPB",
    "description": "Explore surface and volumes of building parts.",
    "warning": "",
    "wiki_url": "",
    "tracker_url": "",
    "category": "Material"}

"""

"""




import bpy
import math
import os
import subprocess
from bpy.props import *
from mathutils import Vector, Matrix
from xml.etree.ElementTree import Element, SubElement, ElementTree
import datetime
from bpy_extras.io_utils import ExportHelper
import bmesh
from bpy.app.handlers import persistent

### Basic useful functions
# Calculate the z projected surface of a face

def faceProjArea(face, obj):
    area = 0.0
    mat = obj.matrix_world

    if len(face.vertices) == 4:
        # Quad
        # Get vertex indices
        v1, v2, v3, v4 = face.vertices

        # Get vertex data
        v1 = obj.data.vertices[v1]
        v2 = obj.data.vertices[v2]
        v3 = obj.data.vertices[v3]
        v4 = obj.data.vertices[v4]

        # Apply transform matrix to vertex coordinates.
        v1 = mat * v1.co
        v2 = mat * v2.co
        v3 = mat * v3.co
        v4 = mat * v4.co
        
        v1[2]=0
        v2[2]=0
        v3[2]=0
        v4[2]=0

        vec1 = v2 - v1
        vec2 = v4 - v1

        n = vec1.cross(vec2)

        area = n.length / 2.0

        vec1 = v4 - v3
        vec2 = v2 - v3

        n = vec1.cross(vec2)

        area += n.length / 2.0

    elif len(face.vertices) == 3:
        # Triangle
        # Get vertex indices
        v1, v2, v3 = face.vertices

        # Get vertex data
        v1 = obj.data.vertices[v1]
        v2 = obj.data.vertices[v2]
        v3 = obj.data.vertices[v3]

        # Apply transform matrix to vertex coordinates.
        v1 = mat * v1.co
        v2 = mat * v2.co
        v3 = mat * v3.co
        
        v1[2]=0
        v2[2]=0
        v3[2]=0

        vec1 = v3 - v2
        vec2 = v1 - v2

        n = vec1.cross(vec2)

        area = n.length / 2.0

    return area

# Calculate the volume of a mesh object.
def objectVolume(obj):
    if (obj and obj.type == 'MESH' and obj.data):

# New volume method for bmesh 2015 corrected 2017        

        bm = bmesh.new()        
        bm.from_object(obj, bpy.context.scene) # could also use from_mesh() if you don't care about deformation etc.
        bmesh.ops.triangulate(bm, faces=bm.faces)
        # print(bm.calc_volume())
        return bm.calc_volume()
    
def create_xml_file(context, filepath):
    print("running write_some_data...")
    import shutil
    temp_file=os.path.expanduser('~/')+'/.blender/ArToKi/artoki_peb_temp.xml'
    shutil.copyfile(temp_file, filepath)
    return {'FINISHED'}

def create_html_file(context, filepath):
    print("running write_some_data...")
    import shutil
    temp_file=os.path.expanduser('~/')+'/.blender/ArToKi/artoki_peb_html_temp.html'
    base_html_folder=os.path.expanduser('~/')+'/.blender/ArToKi/html_files'
    shutil.copyfile(temp_file, filepath)
    print(os.path.split(filepath)[0])
    if os.path.isdir(os.path.split(filepath)[0]+'/html_files'):
        shutil.rmtree(os.path.split(filepath)[0]+'/html_files')
    shutil.copytree(base_html_folder, os.path.split(filepath)[0]+'/html_files') 
    
    
    shutil.copy2(bpy.context.scene.atk_aerial, os.path.split(filepath)[0]+'/html_files/aerial.jpg')
    shutil.copy2(bpy.context.scene.atk_elevation, os.path.split(filepath)[0]+'/html_files/elevation.jpg')
    bpy.context.scene.render.image_settings.file_format='PNG'
    bpy.context.scene.render.image_settings.color_mode='RGBA'
    bpy.context.scene.render.resolution_x=1024
    bpy.context.scene.render.resolution_y=768 
    bpy.context.scene.render.alpha_mode='TRANSPARENT'
    
    cameras_in_scene=[]
    for i in bpy.context.scene.objects:
    
        if i.type == 'CAMERA':
         cameras_in_scene.append(i)
    vue_nb=0
    for j in cameras_in_scene:
        vue_nb=vue_nb+1
        bpy.context.scene.render.filepath=os.path.split(filepath)[0]+'\\html_files\\axono_'+str(vue_nb)+'.jpg'
        bpy.context.scene.camera=j
        bpy.ops.render.opengl(write_still=True)    
    #print(cameras_in_scene)
    print('Trying to start Firefox')
    # windows os.startfile(filepath)
    subprocess.call(('xdg-open',filepath))
    
    
    return {'FINISHED'}    

### Classes
## Report tab 
class OBJECT_PT_ArToKi_Energy_Report(bpy.types.Panel):
    bl_label = "ArToKi - Energy - Report"
    bl_space_type = "PROPERTIES"
    bl_region_type = "WINDOW"
    bl_context = "material"    
    
    bpy.types.Scene.atk_aerial = bpy.props.StringProperty(name="Aerial",description="Aerial view path",default="",subtype='FILE_PATH')
    bpy.types.Scene.atk_elevation = bpy.props.StringProperty(name="Elevation",description="Elevation view path",default="",subtype='FILE_PATH')
    bpy.types.Scene.atk_address1 = bpy.props.StringProperty(name="Address 1",description="Street, nb",default="")
    bpy.types.Scene.atk_address2 = bpy.props.StringProperty(name="Address 2",description="PostCode City",default="")
    bpy.types.Scene.atk_therm_col = bpy.props.BoolProperty(name="Therm col",description="Assign materials colors by performance",default=0)
    bpy.types.Scene.atk_procedure_type = bpy.props.EnumProperty(
        items=[('PAE','PAE','Procédure d\'audit énergétique'),
        ('PEB','PEB','Performances énergétiques des batiments')],
        name="Procedure type", 
        description="Changes the upper left text logo", 
        default="PEB"
        )
 
    def draw(self, context):        
        
        author= 'Maes Thierry'
        author_titles='Auditeur PAE, Certificateur PEB'
        author_adress_1='Rue Joseph Berger, 6'
        author_adress_2='B-1470 Genappe'
        author_e_mail='info@tmaes.be'
        author_phone='+32 (0)67/ 63 68 50'
        author_gsm='+32 (0)475/ 30 36 51'        
        
        #préparation du fichier xml et html temporaires
        obj = context.object
        scene = bpy.context.scene
        now = datetime.datetime.now()       
        base_file=os.path.expanduser('~')+'/.blender/ArToKi/artoki_peb_BASE.xml'
        temp_file=os.path.expanduser('~')+'/.blender/ArToKi/artoki_peb_temp.xml'
        tree = ElementTree(file=base_file)
        base_file_html=os.path.expanduser('~')+'/.blender/ArToKi/artoki_peb_html_BASE.html'
        temp_file_html=os.path.expanduser('~')+'/.blender/ArToKi/artoki_peb_html_temp.html'
        tree_html = ElementTree(file=base_file_html)
        #Bases du fichier xml et html
        root=tree.getroot()
        root_html=tree_html.getroot()
        root.attrib['Version']=bl_info['version']
        project = tree.find('Project')
        project.attrib['Name']=bpy.context.scene.name
        project.attrib['Date']=now.strftime("%Y-%m-%d %H:%M")
        address1 = tree.find('Project/Address1')
        address1.text=str(scene.atk_address1)
        address2 = tree.find('Project/Address2')
        address2.text=str(scene.atk_address2)        

        #placement des éléments statiques du html coordonnées, date etc... header_left
        for i in tree_html.findall(".//td[@class='header_left']"):
            i.text=str(scene.atk_procedure_type)        
        for i in tree_html.findall(".//td[@class='header_street']"):
            i.text=str(scene.atk_address1)
        for i in tree_html.findall(".//td[@class='header_city']"):
            i.text=str(scene.atk_address2)
        for i in tree_html.findall(".//td[@class='aud1']"):
            i.text=str(author)
        for i in tree_html.findall(".//td[@class='aud2']"):
            i.text=str(author_titles)
        for i in tree_html.findall(".//td[@class='aud3']"):
            i.text=str(author_adress_1)
        for i in tree_html.findall(".//td[@class='aud4']"):
            i.text=str(author_adress_2)
        for i in tree_html.findall(".//td[@class='aud5']"):
            i.text=str(author_e_mail)
        for i in tree_html.findall(".//td[@class='aud7']"):
            i.text=str(author_phone)
        for i in tree_html.findall(".//td[@class='aud8']"):
            i.text=str(author_gsm)        
        for i in tree_html.findall(".//td[@class='date']"):
            i.text=now.strftime("%d/%m/%Y")
        
        layout = self.layout 

# début de la table, titres et tout et tout         
# préparation des sélections avec des listes
        faces_base = [face for face in bpy.context.object.data.polygons]
        faces_walls = []
        faces_floors = []
        faces_roofs = []
        faces_temp = []
        faces_types = ['WALLS','FLOORS','ROOFS']
        PROJECTIONS=['S','SSW','SW','WSW','W','WNW','NW','NNW','N','NNE','NE','ENE','E','ESE','SE','SSE']
        FACES=[]           
        
### 1 Création d'une liste contenant: index, surface, orientation, matériau, type de la face, angle, surface projetée et nom du matériau
        
        for a in obj.data.polygons:
            properties=[]  
            properties.append(a.index)
            properties.append(a.area)
            angle_proj=round(math.degrees(math.atan2(a.normal[0],a.normal[1])))
            angle_proj_name='' # pourrait etre ameliore par une fonction
            
            if angle_proj >= -191.25 and angle_proj < -168.75 :
                angle_proj_name='S'               
                
            if angle_proj >= -168.75 and angle_proj < -146.25 :
                angle_proj_name='SSW'                    
                                     
            if angle_proj >= -146.25 and angle_proj < -123.75 :
                angle_proj_name='SW'                
                    
            if angle_proj >= -123.75 and angle_proj < -101.25 :
                angle_proj_name='WSW'                      
                                     
            if angle_proj >= -101.25 and angle_proj < -78.75 :
                angle_proj_name='W'                         
                               
            if angle_proj >= -78.75 and angle_proj < -56.25 :
                angle_proj_name='WNW'                      
                                  
            if angle_proj >= -56.25 and angle_proj < -33.75 :
                angle_proj_name='NW'                                       
                                                                                            
            if angle_proj >= -33.75 and angle_proj < -11.25 :
                angle_proj_name='NNW'                   
                            
            if angle_proj >= -11.25 and angle_proj < 11.25 :
                angle_proj_name='N'                
                    
            if angle_proj >= 11.25 and angle_proj < 33.75 :
                angle_proj_name='NNE'                
                    
            if angle_proj >33.75 and angle_proj < 56.25 :
                angle_proj_name='NE'                
                    
            if angle_proj >= 56.25 and angle_proj < 78.75 :
                angle_proj_name='ENE'                      
                            
            if angle_proj >= 78.75 and angle_proj < 101.25 :
                angle_proj_name='E'                
                    
            if angle_proj >= 101.25 and angle_proj < 123.75 :
                angle_proj_name='ESE'                
                    
            if angle_proj >= 123.75 and angle_proj < 146.25 :
                angle_proj_name='SE'                  
                                                                          
            if angle_proj >= 146.25 and angle_proj < 168.75 :
                angle_proj_name='SSE'                
                    
            if angle_proj >= 168.75 and angle_proj < 191.25 :
                angle_proj_name='S'            
            
            properties.append(angle_proj_name)
            properties.append(bpy.context.object.material_slots[a.material_index].name[0:4])
            
            if context.object.material_slots[a.material_index].name[0:1] == 'M' or context.object.material_slots[a.material_index].name[0:1] == 'W':
                 properties.append(faces_types[0])
            elif context.object.material_slots[a.material_index].name[0:1] == 'S' or context.object.material_slots[a.material_index].name[0:1] == 'F':
                properties.append(faces_types[1])
            elif context.object.material_slots[a.material_index].name[0:1] == 'T' or context.object.material_slots[a.material_index].name[0:1] == 'R':
                properties.append(faces_types[2])            
            if round(math.atan2(a.normal[1],a.normal[2]),3) == 0:
                angle_roof=math.atan2(a.normal[0],a.normal[2])            
            else:
                hypoth= math.sqrt(math.pow(a.normal[0],2)+math.pow(a.normal[1],2))                
                angle_roof=math.atan2(hypoth,a.normal[2])
            properties.append(angle_roof)            
            properties.append(faceProjArea(a, obj))
            properties.append(bpy.context.object.material_slots[a.material_index].name[5:])
            FACES.append(properties)
            
### 1.1 LISTE DES MURS SOLS TOITS POUR L'EXPORT XML

        xml_walls_materials = tree.find('Project/Walls')
        html_walls_materials = tree_html.find(".//table[@id='Table_Walls']")
        xml_floors_materials = tree.find('Project/Floors')
        html_floors_materials = tree_html.find(".//table[@id='Table_Floors']")
        xml_roofs_materials = tree.find('Project/Roofs')
        html_roofs_materials = tree_html.find(".//table[@id='Table_Roofs']")
        for i in bpy.context.object.material_slots:
                xml_surf_mat=0
                
                for j in FACES:
                    if i.name[0:4] == j[3]:
                        xml_surf_mat=xml_surf_mat+j[1]                
                
                if i.name[0]=='M' or i.name[0]=='W':        
                    wall=SubElement(xml_walls_materials,'Wall',Id=i.name[0:4],Name=i.name[5:],Surf=str(round(xml_surf_mat,2)))
                    tr=SubElement(html_walls_materials[1],'tr',id=i.name[0:4])
                    td_1=SubElement(tr,'td')
                    td_1.attrib["class"]="mat_color"
                    td_1.attrib["style"]="color:rgb("+str(int(i.material.diffuse_color.r*255))+","+str(int(i.material.diffuse_color.g*255))+","+str(int(i.material.diffuse_color.b*255))+")"
                    td_1.text="\u25A0"
                    td_2=SubElement(tr,'td')
                    td_2.attrib["class"]="mat_index"
                    td_2.text=i.name[0:4]
                    td_3=SubElement(tr,'td')
                    td_3.attrib["class"]="mat_name"
                    td_3.text=i.name[5:]
                    td_4=SubElement(tr,'td')
                    td_4.attrib["class"]="mat_surf"
                    td_4.text=str(round(xml_surf_mat,2))+" m²"                    
                   
                if i.name[0]=='S' or i.name[0]=='F':
                    floor=SubElement(xml_floors_materials,'Floor',Id=i.name[0:4],Name=i.name[5:],Surf=str(round(xml_surf_mat,2)))
                    tr=SubElement(html_floors_materials[1],'tr',id=i.name[0:4])
                    td_1=SubElement(tr,'td')
                    td_1.attrib["class"]="mat_color"
                    td_1.attrib["style"]="color:rgb("+str(int(i.material.diffuse_color.r*255))+","+str(int(i.material.diffuse_color.g*255))+","+str(int(i.material.diffuse_color.b*255))+")"
                    td_1.text="\u25A0"
                    td_2=SubElement(tr,'td')
                    td_2.attrib["class"]="mat_index"
                    td_2.text=i.name[0:4]
                    td_3=SubElement(tr,'td')
                    td_3.attrib["class"]="mat_name"
                    td_3.text=i.name[5:]
                    td_4=SubElement(tr,'td')
                    td_4.attrib["class"]="mat_surf"
                    td_4.text=str(round(xml_surf_mat,2))+" m²"
                    
                if i.name[0]=='T' or i.name[0]=='R':        
                    roof=SubElement(xml_roofs_materials,'Roof',Id=i.name[0:4],Name=i.name[5:],Surf=str(round(xml_surf_mat,2)))
                    tr=SubElement(html_roofs_materials[1],'tr',id=i.name[0:4])
                    td_1=SubElement(tr,'td')
                    td_1.attrib["class"]="mat_color"
                    td_1.attrib["style"]="color:rgb("+str(int(i.material.diffuse_color.r*255))+","+str(int(i.material.diffuse_color.g*255))+","+str(int(i.material.diffuse_color.b*255))+")"
                    td_1.text="\u25A0"
                    td_2=SubElement(tr,'td')
                    td_2.attrib["class"]="mat_index"
                    td_2.text=i.name[0:4]
                    td_3=SubElement(tr,'td')
                    td_3.attrib["class"]="mat_name"
                    td_3.text=i.name[5:]
                    td_4=SubElement(tr,'td')
                    td_4.attrib["class"]="mat_surf"
                    td_4.text=str(round(xml_surf_mat,2))+" m²"                    
                   
### 2 LISTE DES PROJECTIONS ET DES SURFACES

        row = layout.row()
        row.prop(scene,'atk_procedure_type',text="Procedure")
        row = layout.row()
        row.prop(scene,'atk_aerial',text="Aerial view path")
        row = layout.row()
        row.prop(scene,'atk_elevation',text="Elevation view path")
        row = layout.row()
        row.prop(scene,'atk_address1',text="Street, Nb")
        row = layout.row()
        row.prop(scene,'atk_address2',text="PostCode City")
        row = layout.row()
        row.prop(scene,'atk_therm_col',text="Use thermic colors")
        row = layout.row()
        volume = math.fabs(objectVolume(obj))
        
        #calcul de la surface totale de l'enveloppe
        
        surf_tot=0
        for s in FACES:
            surf_tot=surf_tot+s[1]
        row = layout.row()
        row.alignment = 'EXPAND' 
        box = row.box() 
        col = box.column()
        subrow = col.row(align=True)
        subrow.label(text="Volume of the enveloppe:   " + str(round(volume,2)) + " m\xb3",icon='VIEW3D')
        subrow.label(text="Surface of the enveloppe:   " + str(round(surf_tot,2)) + " m\xb2",icon='MESH_GRID')
        
        xml_volume = tree.find('Project/Volume')
        html_volume= tree_html.find(".//td[@id='general_volume']")
        
        xml_volume.text=str(round(volume,2))
        html_volume.text="Volume total: "+str(round(volume,2))+" m³"
        
        xml_surf_tot = tree.find('Project/Surf_tot')
        html_surf_tot = tree_html.find(".//td[@id='general_surface']")
        
        xml_surf_tot.text=str(round(surf_tot,2))
        html_surf_tot.text="Surface totale: "+str(round(surf_tot,2))+" m²"

### 2.1 MURS
        xml_wall_projections = tree.find('Project/WallProjections')
        html_wall_projections = tree_html.find(".//table[@id='walls_values']")        
        
        projection_id=0
        
        for p in PROJECTIONS:
            faces_proj = []
            mat_proj=[]
            surf_proj = 0
                
            # déterminer les faces de la projection et la surface de la projection
            for g in FACES: 
                if g[2] == p and g[4] == faces_types[0]:
                    faces_proj.append(g)
                    surf_proj=surf_proj+g[1]       
            
            if surf_proj != 0:
                row = layout.row()
                row.alignment = 'EXPAND' 
                box = row.box() 
                col = box.column()
                subrow = col.row(align=True)
                subrow.label(p + " Projection          Surface  : "+ str(round(surf_proj,2)) + " m\xb2",icon='CURSOR')
                # on peut refaire le moteur apd ici...
                subrow = col.row(align=True)              
                subrow.label(text="" + 75*"-")
                projection=SubElement(xml_wall_projections,'WallProjection',Id=str(projection_id), Orientation=str(p), Surf=str(round(surf_proj,2)))
                projection_id=projection_id+1                
                
                for x in faces_proj:
                    if mat_proj.count(str(x[3])) == 0: # si le matériau de la face n'existe pas encore dans mat_proj
                        mat_proj.append(x[3])# ajouter le matériau dans mat_proj [@name='a']
                
                for y in sorted(mat_proj):
                    subrow = col.row(align=True)
                    surf_mat=0
                    for z in faces_proj:
                        if z[3] == y:
                            surf_mat=surf_mat+z[1]
                    subrow.label(5*' '+ y +' : '+ str(round(surf_mat,2))+ " m\xb2",icon='MOD_BUILD')                                     
                    wallpart=SubElement(projection,'WallPart',id=str(y), Surf=str(round(surf_mat,2)))                                    
                
                if projection_id <=4:
                    projection_html_1=SubElement(html_wall_projections[0][1],'td') 
                    projection_html_1_table=SubElement(projection_html_1,'table')  #, Orientation=str(p), Surf=str(round(surf_proj,2))
                    projection_html_1_table.attrib["id"]="walls_projection"
                    tbody=SubElement(projection_html_1_table,'tbody')
                    caption=SubElement(tbody,'caption')  #, Orientation=str(p), Surf=str(round(surf_proj,2))
                    caption.text="Az.: "+str(p)+" - "+str(round(surf_proj,2))+" m²"
                    for x in faces_proj:
                        if mat_proj.count(str(x[3])) == 0: # si le matériau de la face n'existe pas encore dans mat_proj
                            mat_proj.append(x[3])# ajouter le matériau dans mat_proj [@name='a']
                    for y in sorted(mat_proj):
                        surf_mat=0
                        for z in faces_proj:
                            if z[3] == y:
                                surf_mat=surf_mat+z[1]                     
                        tr=SubElement(tbody,'tr')
                        td_1=SubElement(tr,'td')
                        td_1.attrib["class"]="mat_color"
                        for i in bpy.context.object.material_slots:
                            if i.name[0:4]==y:
                                color=i.material.diffuse_color                        
                        td_1.attrib["style"]="color:rgb("+str(int(color.r*255))+","+str(int(color.g*255))+","+str(int(color.b*255))+")"
                        td_1.text="\u25A0"
                        td_2=SubElement(tr,'td')
                        td_2.attrib["class"]="mat_index"
                        td_2.text=str(y)
                        td_3=SubElement(tr,'td')
                        td_3.attrib["class"]="mat_surf"
                        td_3.text=str(round(surf_mat,2))+" m²"
                        
                if projection_id >4:
                    projection_html_1=SubElement(html_wall_projections[0][2],'td') 
                    projection_html_1_table=SubElement(projection_html_1,'table')  #, Orientation=str(p), Surf=str(round(surf_proj,2))
                    projection_html_1_table.attrib["id"]="walls_projection"
                    tbody=SubElement(projection_html_1_table,'tbody')
                    caption=SubElement(tbody,'caption')  #, Orientation=str(p), Surf=str(round(surf_proj,2))
                    caption.text="Az.: "+str(p)+" - "+str(round(surf_proj,2))+" m²"
                    for x in faces_proj:
                        if mat_proj.count(str(x[3])) == 0: # si le matériau de la face n'existe pas encore dans mat_proj
                            mat_proj.append(x[3])# ajouter le matériau dans mat_proj [@name='a']
                    for y in sorted(mat_proj): 
                        surf_mat=0
                        for z in faces_proj:
                            if z[3] == y:
                                surf_mat=surf_mat+z[1]       
                        tr=SubElement(tbody,'tr')
                        td_1=SubElement(tr,'td')
                        td_1.attrib["class"]="mat_color"
                        for i in bpy.context.object.material_slots:
                            if i.name[0:4]==y:
                                color=i.material.diffuse_color                        
                        
                        td_1.attrib["style"]="color:rgb("+str(int(color.r*255))+","+str(int(color.g*255))+","+str(int(color.b*255))+")"
                        td_1.text="\u25A0"
                        td_2=SubElement(tr,'td')
                        td_2.attrib["class"]="mat_index"
                        td_2.text=str(y)
                        td_3=SubElement(tr,'td')
                        td_3.attrib["class"]="mat_surf"
                        td_3.text=str(round(surf_mat,2))+" m²"   

### 2.2 SOLS
        xml_floor_projections = tree.find('Project/FloorProjections')
        html_floors_projection = tree_html.find(".//table[@id='floors_projection']")
        row = layout.row()
        row.alignment = 'EXPAND' 
        box = row.box() 
        col = box.column()              
        surf_vert=0
        faces_vert=[]
        mat_vert=[]
        
        for g in FACES:             
            if g[4] == faces_types[1]:
                faces_vert.append(g)
                surf_vert=surf_vert+ g[6]  
        
        if surf_vert != 0:
            subrow = col.row(align=True)
            subrow.label(text="Floors Projection     Surface : "+str(round(surf_vert,2))+ " m\xb2",icon="TEXTURE")     
            subrow = col.row(align=True)
            subrow.label(text="" + 75*"-")       
            xml_floor_projections.attrib['Surf']=str(round(surf_vert,2))# 
            html_floors_projection.attrib['Surf']=str(round(surf_vert,2))#             
            caption=tree_html.find(".//table[@id='floors_values']/tbody/caption")
            caption.text='Projection Sols: '+str(round(surf_vert,2))+' m²'
                     
            for x in faces_vert:
                    if mat_vert.count(str(x[3])) == 0:
                        mat_vert.append(x[3])
            
            for y in sorted(mat_vert):
                subrow = col.row(align=True)
                surf_mat_vert=0
                for z in faces_vert:
                    if z[3] == y:
                        surf_mat_vert=surf_mat_vert+z[6]
                        
                subrow.label(5*' '+ y +' : '+ str(round(surf_mat_vert,2))+ " m\xb2",icon="ASSET_MANAGER")                      
                floorpart=SubElement(xml_floor_projections,'FloorPart',Id=str(y), Surf=str(round(surf_mat_vert,2))) 
                
                
                tr=SubElement(html_floors_projection[0],'tr')
                td_1=SubElement(tr,'td')
                td_1.attrib["class"]="mat_color"
                
                for i in bpy.context.object.material_slots:
                    if i.name[0:4]==y:
                        color=i.material.diffuse_color              
                td_1.attrib["style"]="color:rgb("+str(int(color.r*255))+","+str(int(color.g*255))+","+str(int(color.b*255))+")"
                td_1.text="\u25A0"
                td_2=SubElement(tr,'td')
                td_2.attrib["class"]="mat_index"
                td_2.text=str(y)
                td_3=SubElement(tr,'td')
                td_3.attrib["class"]="mat_surf"
                td_3.text=str(round(surf_mat_vert,2))+" m²"              
        
### 2.3 TOITURE

        xml_roof_projections = tree.find('Project/RoofProjections')
        html_roofs_projection = tree_html.find(".//table[@id='roofs_projection']")
        row = layout.row()
        row.alignment = 'EXPAND' 
        box = row.box() 
        col = box.column()             
        surf_roof=0
        surf_proj_roof=0
        faces_roof=[]
        mat_roof=[]        
        
        for g in FACES:            
            if g[4] == faces_types[2]:
                faces_roof.append(g)
                surf_roof=surf_roof+ g[1]
                surf_proj_roof=surf_proj_roof+ g[6]   
        
        if surf_roof != 0:
            subrow = col.row(align=True) 
            subrow.label(text="Roofs Projection     Surface : "+str(round(surf_proj_roof,2))+ " m\xb2",icon="LINCURVE")
            subrow = col.row(align=True)
            subrow.label(text="" + 75*"-")  
            xml_roof_projections.attrib['Surf']=str(round(surf_proj_roof,2))#
            html_roofs_projection.attrib['Surf']=str(round(surf_proj_roof,2))#            
            caption=tree_html.find(".//table[@id='roofs_values']/tbody/caption")
            caption.text='Projection Toitures: '+str(round(surf_proj_roof,2))+' m²'
            
            for x in faces_roof:
                    if mat_roof.count(str(x[3])) == 0:
                        mat_roof.append(x[3])
            for y in sorted(mat_roof):                
                subrow = col.row(align=True) 
                surf_mat_roof=0
                surf_proj_mat_roof=0
                roof_angle=0
                roof_orientation=''
                
                for z in faces_roof:                    
                    if z[3] == y:
                        surf_mat_roof=surf_mat_roof+z[1]
                        surf_proj_mat_roof=surf_proj_mat_roof+z[6]
                        roof_angle=z[5]
                        roof_orientation=z[2]
                        
                subrow.label(y +' : '+ str(round(surf_mat_roof,2))+ " m\xb2",icon="MOD_ARRAY") 
                subrow.label('Proj. : '+ str(roof_orientation))                      
                subrow.label('Angle : '+ str(round(math.fabs(math.degrees(roof_angle)),1))+ " \xb0")
                subrow.label('Proj. surf. : '+ str(round(surf_proj_mat_roof,2))+ " m\xb2")
                roofpart=SubElement(
                    xml_roof_projections,
                    'RoofPart',
                    Angle=str(round(math.fabs(math.degrees(roof_angle)),1)),
                    Id=str(y), 
                    Orientation=str(roof_orientation), 
                    Surf=str(round(surf_mat_roof,2)), 
                    SurfProj=str(round(surf_proj_mat_roof,2))
                    )   
                
                tr=SubElement(html_roofs_projection[0],'tr')
                td_1=SubElement(tr,'td')
                td_1.attrib["class"]="mat_color"
                for i in bpy.context.object.material_slots:
                    if i.name[0:4]==y:
                        color=i.material.diffuse_color              
                td_1.attrib["style"]="color:rgb("+str(int(color.r*255))+","+str(int(color.g*255))+","+str(int(color.b*255))+")"
                td_1.text="\u25A0"
                td_2=SubElement(tr,'td')
                td_2.attrib["class"]="mat_index"
                td_2.text=str(y)
                td_3=SubElement(tr,'td')
                td_3.attrib["class"]="mat_surf_brute"
                td_3.text=str(round(surf_mat_roof,2))+" m²"
                td_4=SubElement(tr,'td')
                td_4.attrib["class"]="mat_angle"
                td_4.text=str(round(math.fabs(math.degrees(roof_angle)),1))+" °"
                td_5=SubElement(tr,'td')
                td_5.attrib["class"]="mat_orient"
                td_5.text=str(roof_orientation)
                td_6=SubElement(tr,'td')
                td_6.attrib["class"]="mat_surf_proj"
                td_6.text=str(round(surf_proj_mat_roof,2))+" m²"

        tree.write(temp_file, encoding="UTF-8")
        tree_html.write(temp_file_html, encoding="UTF-8")        
 

# Resume surfaces par materiau
        row = layout.row()
        row.alignment = 'EXPAND' 
        box = row.box() 
        col = box.column()
        subrow = col.row(align=True) 
        subrow.label(text="Walls",icon="MOD_BUILD")
        for i in bpy.context.object.material_slots:
                xml_surf_mat=0
                
                for j in FACES:
                    if i.name[0:4] == j[3]:
                        xml_surf_mat=xml_surf_mat+j[1]                
                
                if i.name[0]=='M' or i.name[0]=='W': 
                    subrow = col.row(align=True) 
                    subrow.label(text=i.name[0:4]+"  "+i.name[5:]+" : ") 
                    subrow.label(text=str(round(xml_surf_mat,2))+ " m\xb2")  
                    
        col = box.column()
        subrow = col.row(align=True) 
        col.label(text="Floors",icon="TEXTURE")                    
        for i in bpy.context.object.material_slots:
                xml_surf_mat=0
                
                for j in FACES:
                    if i.name[0:4] == j[3]:
                        xml_surf_mat=xml_surf_mat+j[1]                
                
                if i.name[0]=='S' or i.name[0]=='F': 
                    subrow = col.row(align=True) 
                    subrow.label(text=i.name[0:4]+"  "+i.name[5:]+" : ") 
                    subrow.label(text=str(round(xml_surf_mat,2))+ " m\xb2") 
                    
        col = box.column()
        subrow = col.row(align=True) 
        col.label(text="Roofs",icon="LINCURVE")                    
        for i in bpy.context.object.material_slots:
                xml_surf_mat=0
                
                for j in FACES:
                    if i.name[0:4] == j[3]:
                        xml_surf_mat=xml_surf_mat+j[1]                
                
                if i.name[0]=='T' or i.name[0]=='R': 
                    subrow = col.row(align=True) 
                    subrow.label(text=i.name[0:4]+"  "+i.name[5:]+" : ") 
                    subrow.label(text=str(round(xml_surf_mat,2))+ " m\xb2") 

# buttons & credits

        row = layout.row()
        row.operator("export.xml",text="Save")
        row.operator("export.html",text="Export to pdf...")
        
        row = layout.row()
        dirname = os.path.expanduser('~')+'\.blender\ArToKi\labels'   #### Only line to change for lite version for windows
    
        if bpy.data.images.find('ArToKi.png') == -1:
            img_A_Plus = bpy.data.images.load(os.path.join(dirname, 'ArToKi.png'))
            img_A_Plus.use_alpha = True
            img_A_Plus.user_clear() # Won't get saved into .blend files
        icon_ArToKi = self.layout.icon(bpy.data.images['ArToKi.png'])
        row.label(text="ArToKi - Energy by tmaes"+60*" "+"info@tmaes.be", icon_value=icon_ArToKi)
        
## Classes for export

class EXPORT_OT_XML(bpy.types.Operator, ExportHelper):
    '''This appears in the tooltip of the operator and in the generated docs.'''
    bl_idname = "export.xml"  # this is important since its how bpy.ops.export.some_data is constructed
    bl_label = "Export to .xml"

    # ExportHelper mixin class uses this
    filename_ext = ".xml"

    filter_glob = StringProperty(
            default="*.xml",
            options={'HIDDEN'},
            )

    @classmethod
    def poll(cls, context):
        return context.active_object is not None

    def execute(self, context):
        return create_xml_file(context, self.filepath)
    

class EXPORT_OT_HTML(bpy.types.Operator, ExportHelper):
    '''This appears in the tooltip of the operator and in the generated docs.'''
    bl_idname = "export.html"  # this is important since its how bpy.ops.export.some_data is constructed
    bl_label = "Export to .html"

    # ExportHelper mixin class uses this
    filename_ext = ".html"

    filter_glob = StringProperty(
            default="*.html",
            options={'HIDDEN'},
            )

    @classmethod
    def poll(cls, context):
        return context.active_object is not None

    def execute(self, context):

        return create_html_file(context, self.filepath)
      
## Class for Deperditions
        
class OBJECT_PT_ArToKi_Energy_Deperditions(bpy.types.Panel):
    bl_label = "ArToKi - Energy - Deperditions (alpha)"
    bl_space_type = "PROPERTIES"
    bl_region_type = "WINDOW"
    bl_context = "material"    
            
    levels=[]
    for i in range(0,11): 
        levels.append((str(i), str(i), "Layers composing walls, roofs etc..."))
    environnement=[
        ('Outside','Outside','Outside'),
        ('Unprotected space','Unprotected space','Unprotected space'),
        ('Protected space (no freeze)','Protected space (no freeze)','Protected space (no freeze)'),
        ('Ground','Ground','Ground'),('Heated space', 'Heated space','Heated space')
        ]

    materials=[
        ('Free air','Free air','Free air',0),
        ('Semi Static air','Semi Static air','Semi Static air',1),
        ('Static air','Static air','Static air',2),
        ('Masonry','Masonry','Masonry',3),
        ('Wood','Wood','Wood',4),
        ('Insulation','Insulation','Insulation',5),
        ]           

    bpy.types.Material.mat_color=bpy.types.Material.myColor = bpy.props.FloatVectorProperty(name = "myColor",subtype = "COLOR",size = 4,min = 0.0,max = 1.0,default = (0.75,0.0,0.8,1.0))
    bpy.types.Material.mat_layers = bpy.props.EnumProperty(items=levels,name="Material layers",default='0')
    bpy.types.Material.mat_environnement = bpy.props.EnumProperty(items=environnement,name="Outside conditions",default='Outside')
    
    bpy.types.Material.mat_depth_1 = bpy.props.FloatProperty(name="Material 1 depth",precision=1)
    bpy.types.Material.mat_depth_2 = bpy.props.FloatProperty(name="Material 2 depth",precision=1)
    bpy.types.Material.mat_depth_3 = bpy.props.FloatProperty(name="Material 3 depth",precision=1)
    bpy.types.Material.mat_depth_4 = bpy.props.FloatProperty(name="Material 4 depth",precision=1)
    bpy.types.Material.mat_depth_5 = bpy.props.FloatProperty(name="Material 5 depth",precision=1)
    bpy.types.Material.mat_depth_6 = bpy.props.FloatProperty(name="Material 6 depth",precision=1)
    bpy.types.Material.mat_depth_7 = bpy.props.FloatProperty(name="Material 7 depth",precision=1)
    bpy.types.Material.mat_depth_8 = bpy.props.FloatProperty(name="Material 8 depth",precision=1)
    bpy.types.Material.mat_depth_9 = bpy.props.FloatProperty(name="Material 9 depth",precision=1)
    bpy.types.Material.mat_depth_10 = bpy.props.FloatProperty(name="Material 10 depth",precision=1)
    
    bpy.types.Material.mat_lambda_i_1 = bpy.props.FloatProperty(name="Material 1 lambda_i",precision=3)
    bpy.types.Material.mat_lambda_i_2 = bpy.props.FloatProperty(name="Material 2 lambda_i",precision=3)
    bpy.types.Material.mat_lambda_i_3 = bpy.props.FloatProperty(name="Material 3 lambda_i",precision=3)
    bpy.types.Material.mat_lambda_i_4 = bpy.props.FloatProperty(name="Material 4 lambda_i",precision=3)
    bpy.types.Material.mat_lambda_i_5 = bpy.props.FloatProperty(name="Material 5 lambda_i",precision=3)
    bpy.types.Material.mat_lambda_i_6 = bpy.props.FloatProperty(name="Material 6 lambda_i",precision=3)
    bpy.types.Material.mat_lambda_i_7 = bpy.props.FloatProperty(name="Material 7 lambda_i",precision=3)
    bpy.types.Material.mat_lambda_i_8 = bpy.props.FloatProperty(name="Material 8 lambda_i",precision=3)
    bpy.types.Material.mat_lambda_i_9 = bpy.props.FloatProperty(name="Material 9 lambda_i",precision=3)
    bpy.types.Material.mat_lambda_i_10 = bpy.props.FloatProperty(name="Material 10 lambda_i",precision=3)
    
    bpy.types.Material.mat_lambda_e_1 = bpy.props.FloatProperty(name="Material 1 lambda_e",precision=3)
    bpy.types.Material.mat_lambda_e_2 = bpy.props.FloatProperty(name="Material 2 lambda_e",precision=3)
    bpy.types.Material.mat_lambda_e_3 = bpy.props.FloatProperty(name="Material 3 lambda_e",precision=3)
    bpy.types.Material.mat_lambda_e_4 = bpy.props.FloatProperty(name="Material 4 lambda_e",precision=3)
    bpy.types.Material.mat_lambda_e_5 = bpy.props.FloatProperty(name="Material 5 lambda_e",precision=3)
    bpy.types.Material.mat_lambda_e_6 = bpy.props.FloatProperty(name="Material 6 lambda_e",precision=3)
    bpy.types.Material.mat_lambda_e_7 = bpy.props.FloatProperty(name="Material 7 lambda_e",precision=3)
    bpy.types.Material.mat_lambda_e_8 = bpy.props.FloatProperty(name="Material 8 lambda_e",precision=3)
    bpy.types.Material.mat_lambda_e_9 = bpy.props.FloatProperty(name="Material 9 lambda_e",precision=3)
    bpy.types.Material.mat_lambda_e_10 = bpy.props.FloatProperty(name="Material 10 lambda_e",precision=3)
    
    bpy.types.Material.mat_R_1 = 0
    bpy.types.Material.mat_R_2 = bpy.props.FloatProperty(name="Material 2 R",precision=2)
    bpy.types.Material.mat_R_3 = bpy.props.FloatProperty(name="Material 3 R",precision=2)
    bpy.types.Material.mat_R_4 = bpy.props.FloatProperty(name="Material 4 R",precision=2)
    bpy.types.Material.mat_R_5 = bpy.props.FloatProperty(name="Material 5 R",precision=2)
    bpy.types.Material.mat_R_6 = bpy.props.FloatProperty(name="Material 6 R",precision=2)
    bpy.types.Material.mat_R_7 = bpy.props.FloatProperty(name="Material 7 R",precision=2)
    bpy.types.Material.mat_R_8 = bpy.props.FloatProperty(name="Material 8 R",precision=2)
    bpy.types.Material.mat_R_9 = bpy.props.FloatProperty(name="Material 9 R",precision=2)
    bpy.types.Material.mat_R_10 = bpy.props.FloatProperty(name="Material 10 R",precision=2)    

    bpy.types.Material.materials_1 = bpy.props.EnumProperty(items=materials,name="Materials",default='Free air')
    bpy.types.Material.materials_2 = bpy.props.EnumProperty(items=materials,name="Materials",default='Free air')
    bpy.types.Material.materials_3 = bpy.props.EnumProperty(items=materials,name="Materials",default='Free air')
    bpy.types.Material.materials_4 = bpy.props.EnumProperty(items=materials,name="Materials",default='Free air')
    bpy.types.Material.materials_5 = bpy.props.EnumProperty(items=materials,name="Materials",default='Free air')
    bpy.types.Material.materials_6 = bpy.props.EnumProperty(items=materials,name="Materials",default='Free air')
    bpy.types.Material.materials_7 = bpy.props.EnumProperty(items=materials,name="Materials",default='Free air')
    bpy.types.Material.materials_8 = bpy.props.EnumProperty(items=materials,name="Materials",default='Free air')
    bpy.types.Material.materials_9 = bpy.props.EnumProperty(items=materials,name="Materials",default='Free air')
    bpy.types.Material.materials_10 = bpy.props.EnumProperty(items=materials,name="Materials",default='Free air')

    

    def draw(self, context):
        layout = self.layout 
        scene = bpy.context.scene  
        mat = bpy.context.object.active_material      
        R_tot=0
        U_tot=0
        Air=0
        W_Rse=0.13
        W_Rsi=0.13
        G_Rse=0.17
        G_Rsi=0.17
        R_Rse=0.1
        R_Rsi=0.1 
        R_levels=[]
        row = layout.row(align=True)
        row.alignment = 'LEFT' 
        row.label(text="Levels:" )     
        row.prop(mat,'mat_layers',text="") 
        row.label(text="Environnement:" ) 
        row.prop(mat,'mat_environnement',text="")     
        row = layout.row()
        row.label(text="Outside", icon='LAMP_SUN')
        
        dirname = os.path.expanduser('~')+'/.blender/ArToKi/labels'
    
#Those should be serialized:
    
        if bpy.data.images.find('ArToKi.png') == -1:
            img = bpy.data.images.load(os.path.join(dirname, 'ArToKi.png'))
            img.use_alpha = True
            img.user_clear() # Won't get saved into .blend files

        if bpy.data.images.find('A_Plus_Plus.png') == -1:
            img = bpy.data.images.load(os.path.join(dirname, 'A_Plus_Plus.png'))
            img.use_alpha = True
            img.user_clear() # Won't get saved into .blend files

        if bpy.data.images.find('A_Plus.png') == -1:
            img = bpy.data.images.load(os.path.join(dirname, 'A_Plus.png'))
            img.use_alpha = True
            img.user_clear() # Won't get saved into .blend files

        if bpy.data.images.find('A.png') == -1:
            img = bpy.data.images.load(os.path.join(dirname, 'A.png'))
            img.use_alpha = True
            img.user_clear() # Won't get saved into .blend files

        if bpy.data.images.find('B.png') == -1:
            img = bpy.data.images.load(os.path.join(dirname, 'B.png'))
            img.use_alpha = True
            img.user_clear() # Won't get saved into .blend files

        if bpy.data.images.find('C.png') == -1:
            img = bpy.data.images.load(os.path.join(dirname, 'C.png'))
            img.use_alpha = True
            img.user_clear() # Won't get saved into .blend files

        if bpy.data.images.find('D.png') == -1:
            img = bpy.data.images.load(os.path.join(dirname, 'D.png'))
            img.use_alpha = True
            img.user_clear() # Won't get saved into .blend files

        if bpy.data.images.find('E.png') == -1:
            img = bpy.data.images.load(os.path.join(dirname, 'E.png'))
            img.use_alpha = True
            img.user_clear() # Won't get saved into .blend files

        if bpy.data.images.find('F.png') == -1:
            img = bpy.data.images.load(os.path.join(dirname, 'F.png'))
            img.use_alpha = True
            img.user_clear() # Won't get saved into .blend files

        if bpy.data.images.find('G.png') == -1:
            img = bpy.data.images.load(os.path.join(dirname, 'G.png'))
            img.use_alpha = True
            img.user_clear() # Won't get saved into .blend files 
            
        for i in range (int(mat.mat_layers)):            
            row = layout.row()
            box = row.box() 
            col = box.column()
            subrow = col.row(align=True)
            subrow.alignment = 'EXPAND'
            subrow.label(text="Level "+str(i+1), icon='SORTSIZE')  
            R_mat=0
            U_mat=0
            if mat.name[0:1] == 'M' or mat.name[0:1] == 'W': 
                if getattr(mat,'materials_'+str(i+1)) == 'Semi Static air': 
                    Air=1  
                    if getattr(mat,'mat_depth_'+str(i+1)) != 0:
                        R_mat =0.09             
                        U_mat=1/R_mat 
            
                elif getattr(mat,'materials_'+str(i+1)) == 'Static air': 
                    Air=2  
                    if getattr(mat,'mat_depth_'+str(i+1)) != 0:
                        R_mat =0.18             
                        U_mat=1/R_mat 
                elif getattr(mat,'materials_'+str(i+1)) == 'Free air': 
                    Air=0 
                    if getattr(mat,'mat_depth_'+str(i+1)) != 0: 
                        R_mat =0             
                        U_mat=0                       
            if mat.name[0:1] == 'S' or mat.name[0:1] == 'F': 
                if getattr(mat,'materials_'+str(i+1)) == 'Semi Static air': 
                    Air=1  
                    if getattr(mat,'mat_depth_'+str(i+1)) != 0:
                        R_mat =0.1             
                        U_mat=1/R_mat 
            
                elif getattr(mat,'materials_'+str(i+1)) == 'Static air': 
                    Air=2  
                    if getattr(mat,'mat_depth_'+str(i+1)) != 0:
                        R_mat =0.19             
                        U_mat=1/R_mat 
                elif getattr(mat,'materials_'+str(i+1)) == 'Free air': 
                    Air=0  
                    if getattr(mat,'mat_depth_'+str(i+1)) != 0:
                        R_mat =0             
                        U_mat=0 
            if mat.name[0:1] == 'T' or mat.name[0:1] == 'R': 
                if getattr(mat,'materials_'+str(i+1)) == 'Semi Static air': 
                    Air=1  
                    if getattr(mat,'mat_depth_'+str(i+1)) != 0:
                        R_mat =0.08             
                        U_mat=1/R_mat 
            
                elif getattr(mat,'materials_'+str(i+1)) == 'Static air': 
                    Air=2  
                    if getattr(mat,'mat_depth_'+str(i+1)) != 0:
                        R_mat =0.16             
                        U_mat=1/R_mat 
                elif getattr(mat,'materials_'+str(i+1)) == 'Free air': 
                    Air=0  
                    if getattr(mat,'mat_depth_'+str(i+1)) != 0:                        
                        R_mat =0             
                        U_mat=0                         
            if getattr(mat,'mat_lambda_i_'+str(i+1)) != 0:              
                R_mat=getattr(mat,'mat_depth_'+str(i+1))/100/getattr(mat,'mat_lambda_i_'+str(i+1))                
                
                if getattr(mat,'mat_depth_'+str(i+1)) != 0:
                    U_mat=1/R_mat
            R_levels.append(round(R_mat,2))     

            subrow.label(text="R = "+str(round(R_mat,3))+" m².K/W")   #+"mat_R_"+str(i+1))
            #subrow.label(text="U = "+str(round(U_mat,2))+" W/m².K")   #+"mat_R_"+str(i+1))
            subrow.prop(mat,'materials_'+str(i+1),text="")
           
            row = box.row(align=True)
            row.alignment = 'LEFT'                
            row.prop(mat,'mat_depth_'+str(i+1),text="Depth (cm)")             
            row.prop(mat,'mat_lambda_i_'+str(i+1),text="λi (W/mK)")
                      
            # for more precision #row.prop(bpy.data.materials[mat.name],'mat_lambda_e_'+str(i+1),text="λe(W/mK)")# function to precise... λe for humidity
            # for more precision #row.prop(bpy.data.materials[mat.name],'mat_exterior_'+str(i+1),text="Exterior")

  

        row = layout.row()        
        row.label(text="Inside", icon='UGLYPACKAGE')
        if mat.mat_environnement == 'Outside' or mat.mat_environnement == 'Ground':
            if Air==1 or Air==2:
                W_Rse=0.04
                G_Rse=0.04
                R_Rse=0.04
                
                # Rtot calculation
   
        if sum(R_levels)!=0:            
            if mat.name[0:1] == 'M' or mat.name[0:1] == 'W':           
                R_tot=W_Rse+sum(R_levels)+W_Rsi
            if mat.name[0:1] == 'S' or mat.name[0:1] == 'F':           
                R_tot=G_Rse+sum(R_levels)+G_Rsi
            if mat.name[0:1] == 'T' or mat.name[0:1] == 'R':         
                R_tot=R_Rse+sum(R_levels)+R_Rsi     
            if R_tot != 0:
                U_tot=1/R_tot               
        row = layout.row()        
        box = row.box() 
        col = box.column()
        subrow = col.row(align=True)
        subrow.alignment = 'LEFT'        
        icon_A_Plus_Plus = self.layout.icon(bpy.data.images['A_Plus_Plus.png'])
        icon_A_Plus = self.layout.icon(bpy.data.images['A_Plus.png'])
        icon_A = self.layout.icon(bpy.data.images['A.png'])
        icon_B = self.layout.icon(bpy.data.images['B.png'])
        icon_C = self.layout.icon(bpy.data.images['C.png'])
        icon_D = self.layout.icon(bpy.data.images['D.png'])
        icon_E = self.layout.icon(bpy.data.images['E.png'])
        icon_F = self.layout.icon(bpy.data.images['F.png'])
        icon_G = self.layout.icon(bpy.data.images['G.png'])       
        
        # Label assign
                
        if mat.name[0:1] == 'M' or mat.name[0:1] == 'W': 
            if round(U_tot,3)<=0.15:
                subrow.label(text="", icon_value=icon_A_Plus_Plus)
#                if scene.atk_therm_col == True:
#                    mat.diffuse_color=((0,0.215686275,0.090196078))
            elif 0.15<round(U_tot,3)<=0.18:
                subrow.label(text="", icon_value=icon_A_Plus)
                #mat.diffuse_color=((0.02,0.41,0.19))            
            elif 0.18<round(U_tot,3)<=0.24:
                subrow.label(text="", icon_value=icon_A)
                #mat.diffuse_color=((0.26,0.54,0.01))              
            elif 0.24<round(U_tot,3)<=0.32:
                subrow.label(text="", icon_value=icon_B)            
            elif 0.32<round(U_tot,3)<=0.40:
                subrow.label(text="", icon_value=icon_C)
            elif 0.40<round(U_tot,3)<=0.60:
                subrow.label(text="", icon_value=icon_D)
            elif 0.60<round(U_tot,3)<=0.90:
                subrow.label(text="", icon_value=icon_E)
            elif 0.90<round(U_tot,3)<=1.6:
                subrow.label(text="", icon_value=icon_F)
            elif 1.6<round(U_tot,3):
                subrow.label(text="", icon_value=icon_G) 
                 
        if mat.name[0:1] == 'S' or mat.name[0:1] == 'F': 
            if round(U_tot,3)<=0.15:
                subrow.label(text="", icon_value=icon_A_Plus_Plus)
                #mat.diffuse_color=((0,0.215686275,0.090196078))
            elif 0.15<round(U_tot,3)<=0.18:
                subrow.label(text="", icon_value=icon_A_Plus)
                #mat.diffuse_color=((0.02,0.41,0.19))              
            elif 0.18<round(U_tot,3)<=0.30:
                subrow.label(text="", icon_value=icon_A)
                #mat.diffuse_color=((0.26,0.54,0.01))             
            elif 0.30<round(U_tot,3)<=0.35:
                subrow.label(text="", icon_value=icon_B)            
            elif 0.35<round(U_tot,3)<=0.40:
                subrow.label(text="", icon_value=icon_C)
            elif 0.40<round(U_tot,3)<=0.60:
                subrow.label(text="", icon_value=icon_D)
            elif 0.60<round(U_tot,3)<=0.90:
                subrow.label(text="", icon_value=icon_E)
            elif 0.90<round(U_tot,3)<=1.6:
                subrow.label(text="", icon_value=icon_F)
            elif 1.6<round(U_tot,3):
                subrow.label(text="", icon_value=icon_G)  
                
        if mat.name[0:1] == 'T' or mat.name[0:1] == 'R': 
            if round(U_tot,3)<=0.15:
                subrow.label(text="", icon_value=icon_A_Plus_Plus)
                #mat.diffuse_color=((0,0.215686275,0.090196078))
            elif 0.15<round(U_tot,3)<=0.18:
                subrow.label(text="", icon_value=icon_A_Plus)
                #mat.diffuse_color=((0.02,0.41,0.19))              
            elif 0.18<round(U_tot,3)<=0.24:
                subrow.label(text="", icon_value=icon_A)
                #mat.diffuse_color=((0.26,0.54,0.01))             
            elif 0.24<round(U_tot,3)<=0.27:
                subrow.label(text="", icon_value=icon_B)            
            elif 0.27<round(U_tot,3)<=0.30:
                subrow.label(text="", icon_value=icon_C)
            elif 0.30<round(U_tot,3)<=0.40:
                subrow.label(text="", icon_value=icon_D)
            elif 0.40<round(U_tot,3)<=0.65:
                subrow.label(text="", icon_value=icon_E)
            elif 0.65<round(U_tot,3)<=1.80:
                subrow.label(text="", icon_value=icon_F)
            elif 1.8<round(U_tot,3):
                subrow.label(text="", icon_value=icon_G)  
                       
        subrow.label(text="  Rt = "+str(round(R_tot,3))+" m².K/W             U= "+str(round(U_tot,3))+" W/m².K          ")#+str(mat.mat_layers)  +str(W_Rse)+"    "+str(W_Rsi)+"    "+str(Air)+"    "+str(R_levels) )    
#        subrow = col.row(align=True) 
#        subrow.label(text="#dev Levels: "+str(mat.mat_layers)  +"     W_R se: "+str(W_Rse)+"     W_R si: "+str(W_Rsi)+"     Air : "+str(Air)+"     R levels: "+str(R_levels))
#        subrow = col.row(align=True)
#        subrow.label(text="#dev Levels: "+str(mat.mat_layers)  +"     G_R se: "+str(G_Rse)+"     G_R si: "+str(G_Rsi)+"     Air : "+str(Air)+"     R levels: "+str(R_levels))
#        subrow = col.row(align=True)
#        subrow.label(text="#dev Levels: "+str(mat.mat_layers)  +"     R_R se: "+str(R_Rse)+"     R_R si: "+str(R_Rsi)+"     Air : "+str(Air)+"     R levels: "+str(R_levels))

# registering and menu integration
def register():
    bpy.utils.register_class(OBJECT_PT_ArToKi_Energy_Report)
    bpy.utils.register_class(OBJECT_PT_ArToKi_Energy_Deperditions)
    bpy.utils.register_class(EXPORT_OT_XML) 
    bpy.utils.register_class(EXPORT_OT_HTML)
 
# unregistering and removing menus
def unregister():
    bpy.utils.unregister_class(OBJECT_PT_ArToKi_PEB_Energy_Report)
    bpy.utils.unregister_class(OBJECT_PT_ArToKi_Energy_Deperditions)
    bpy.utils.unregister_class(EXPORT_OT_XML)
    bpy.utils.unregister_class(EXPORT_OT_HTML)
 
if __name__ == "__main__":
    register()